@@ -38,7 +38,7 @@ use PPIx::QuoteLike::Utils qw{
 use Scalar::Util ();
 use Text::Tabs ();
 
-our $VERSION = '0.009_02';
+our $VERSION = '0.010_01';
 
 use constant CLASS_CONTROL       => 'PPIx::QuoteLike::Token::Control';
 use constant CLASS_DELIMITER     => 'PPIx::QuoteLike::Token::Delimiter';
@@ -210,6 +210,10 @@ $PPIx::QuoteLike::DEFAULT_POSTDEREF = 1;
 			[ CLASS_UNKNOWN, $seq,
 			    error => "Unknown charname '$name'" ] :
 			[ CLASS_STRING, $seq ];
+		# NOTE in the following that I do not read perldata as
+		# saying there can be space between the sigil and the
+		# variable name, but Perl itself seems to accept it as
+		# of 5.30.1.
 		} elsif ( $content =~ m/ \G ( [\$\@] \#? \$* ) /smxgc ) {
 		    push @children, $self->_interpolation( "$1", $content );
 		} elsif ( $content =~ m/ \G ( \\ . | [^\\\$\@]+ ) /smxgc ) {
@@ -719,7 +723,7 @@ sub _link_elems {
 	    {
 		use re qw{ eval };
 		local $" = '|';
-		$REGEXP_CACHE{$ql} = qr/($ql(?:@parts)*$qr)/;
+		$REGEXP_CACHE{$ql} = qr/($ql(?:@parts)*$qr)/sm;
 	    }
 
 	    return $REGEXP_CACHE{$ql};
@@ -859,6 +863,17 @@ reasonably like string literals. Its real reason for being is to find
 interpolated variables for L<Perl::Critic|Perl::Critic> policies and
 similar code.
 
+=head1 DEPRECATION NOTICE
+
+The L<postderef|/postderef> argument to L<new()|/new> is being put
+through a deprecation cycle and retracted. After the retraction, postfix
+dereferences will always be recognized. This is the default behaviour
+now.
+
+Starting with the first release after October 1 2020, the first use of
+this argument will warn. Six months after that all uses will warn. After
+a further six months, all uses will become fatal.
+
 =head1 INHERITANCE
 
 C<PPIx::QuoteLike> is not descended from any other class.
@@ -923,6 +938,9 @@ L<PPI::Element|PPI::Element>, otherwise no locations will be available.
 
 =item postderef
 
+B<THIS ARGUMENT IS DEPRECATED>.
+See L<DEPRECATION NOTICE|/DEPRECATION NOTICE> above for the details.
+
 This Boolean argument determines whether postfix dereferencing is
 recognized in interpolation. If unspecified, or specified as C<undef>,
 it defaults to the value of C<$PPIx::QuoteLike::DEFAULT_POSTDEREF>. This
